@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 def atomic_push(redis_db, queue_id, item):
-    """ Push item to queue and get queue updated length in
+    """ Push item to queue and get item position in
     one atomic operation by using transaction. """
     pipe = redis_db.pipeline()
     pipe.rpush(queue_id, item)
